# Generated by roxygen2: do not edit by hand

export(calculate_entropy)
export(calculate_hellinger_matrix)
export(cluster_sites_by_entropy)
export(decode_aa_sequence)
export(detect_changepoints_ecp)
export(detect_changepoints_hdcp)
export(encode_aa_sequence)
export(extract_fasta_countries)
export(extract_fasta_dates)
export(fasta_to_char_matrix)
export(filter_ambiguous_sequences)
export(partition_time_windows)
export(plot_entropy_trajectories)
export(plot_site_class_trajectory)
export(relabel_entropy_classes)
export(simulate_variant_evolution)
export(tabulate_site_evolution)
importFrom(HDcpDetect,binary.segmentation)
importFrom(HDcpDetect,wild.binary.segmentation)
importFrom(ecp,ks.cp3o)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,expansion)
importFrom(ggplot2,geom_label)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_grey)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_linewidth_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(grDevices,hcl.colors)
importFrom(kableExtra,column_spec)
importFrom(kableExtra,kable)
importFrom(kableExtra,kable_styling)
importFrom(kableExtra,save_kable)
importFrom(lubridate,"%m+%")
importFrom(lubridate,"%m-%")
importFrom(lubridate,interval)
importFrom(lubridate,period)
importFrom(magrittr,"%>%")
importFrom(mclust,Mclust)
importFrom(mclust,mclustBIC)
importFrom(rlang,.data)
importFrom(stats,aggregate)
importFrom(stats,rbinom)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stringr,str_extract)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
importFrom(zoo,as.Date)
importFrom(zoo,as.yearmon)
